@@ -213,7 +213,7 @@ def main():
         +"-p, --pic [a,b,c]\tThe list of images would be shown (default: all)\n"\
         +"-f, --filter [aaa,bbb]\tThe list of chromosomes which should be filtered (default: none)\n"\
         +"-w, --widthtss [100-10000]\tThe width of regions around the TSS (default: 900)\n"\
-        +"-d, --delmt\tRemove mtDNA in fragment distribution calculation\n"
+        +"-d, --delmt\tRemove mtDNA in fragment distribution (default: False)\n"
     for opt, arg in opts:
         if opt in ("-h", "--help"):
             help_flag = True
